import { Breakpoint } from './types';
import { LqipOptions } from './processingPrimitives';
import { WebpOptions, JpegOptions, PngOptions } from 'sharp';
export declare type ProcessedImage = {
    src: string;
    srcSet: string;
    srcWebp?: string;
    srcSetWebp?: string;
    sizes?: string;
    aspectRatio: number;
    lqip?: string;
};
export interface IProcessImage {
    /**
     * an absolute file path - local or remote
     */
    imageUrl: string;
    breakpoints: Breakpoint[];
    multipliers?: number[];
    withLqip?: boolean;
    withWebp?: boolean;
    lqipOptions?: LqipOptions;
    webpOptions?: WebpOptions;
    orgOptions?: JpegOptions | PngOptions;
    /**
     * Absolute directory path that the processed images should be saved to
     */
    dir: string;
    /**
     * The dir that the images will be accessed from. TODO: explain more
     */
    publicDir: string;
}
export declare function processImage({ imageUrl, breakpoints, multipliers, withWebp, withLqip, lqipOptions, webpOptions, orgOptions, dir, publicDir, }: IProcessImage): Promise<ProcessedImage>;
